# Mandatory Attributes
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/mandatory-attributes#introduction)
  * [Filling Mandatory Attributes](https://help.sap.com/docs/leanix/ea/mandatory-attributes#filling-mandatory-attributes)
  * [Mandatory Attributes and Quality Seal](https://help.sap.com/docs/leanix/ea/mandatory-attributes#mandatory-attributes-and-quality-seal)
  * [Defining Mandatory Attributes](https://help.sap.com/docs/leanix/ea/mandatory-attributes#defining-mandatory-attributes)
  * [Interoperability of Mandatory and Conditional Attributes](https://help.sap.com/docs/leanix/ea/mandatory-attributes#interoperability-of-mandatory-and-conditional-attributes)


Mandatory attributes are essential fields specified by admins to ensure data integrity and quality in fact sheets. They must be filled out for fact sheets to approve quality seal, ensuring consistent and reliable information.
